# Overview
**AllOverIt** began as a single nuget package of the same name in 2015. Since then, the library has broadened and deepened in functionality, resulting in a comprehensive set of dedicated nuget packages that encompass a number of different domains.

Refer to the [Change Log](ChangeLog.md) for an overview of what has recently changed.

Refer to the online [Documentation](https://alloverit.mjfreelancing.com) for comprehensive usage information.

A summary for each of the available packages is provided below.

## AllOverIt
This general-purpose package contains a diverse range of classes and utility functions, intended to tackle a wide array of commonly encountered issues.

Key areas of concern include threading, tasks, generic caching, event (message) aggregation, expression and reflection utilities, plugin contexts, enriched enums, pipelines, value objects, specifications, and dozens of extensions.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt?color=E3505C)](https://www.nuget.org/packages/AllOverIt/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt?color=FFC33C)](https://www.nuget.org/packages/AllOverIt/absoluteLatest/)

---


## AllOverIt.AspNetCore

This package provides useful ASP.NET Core utilities such as custom model binding for **AllOverIt** based enriched enum types, and arrays of values in a query string.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.AspNetCore?color=E3505C)](https://www.nuget.org/packages/AllOverIt.AspNetCore/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.AspNetCore?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.AspNetCore/absoluteLatest/)

---


## AllOverIt.Assertion

This package contains a useful collection of pre- and post-condition assertion extension methods, and a fluent-like approach to throwing exceptions based on a given condition or custom predicate.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Assertion?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Assertion/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Assertion?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Assertion/absoluteLatest/)

---


## AllOverIt.Aws.AppSync.Client

This package contains AWS AppSync GraphQL and Subscription clients with support for serialization using Newtonsoft or System.Text, including serialization of **AllOverIt** based enriched enums.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Aws.AppSync.Client?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Aws.AppSync.Client/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Aws.AppSync.Client?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Aws.AppSync.Client/absoluteLatest/)

---


## AllOverIt.Aws.Cdk.AppSync

This package greatly simplifies the generation of AWS Graphql schemas, including their associated mapping and resolver configuration, using a code-first approach.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Aws.Cdk.AppSync?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Aws.Cdk.AppSync/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Aws.Cdk.AppSync?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Aws.Cdk.AppSync/absoluteLatest/)

---


## AllOverIt.Cryptography

This package provides byte-array and stream-based interfaces for encryption algorithms such as AES, RSA and an RSA-AES hybrid. It also includes useful extension methods that greatly simplifies the encryption and decryption between byte-arrays, streams, plain text and base64 encoded versions of plain text and cipher text.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Cryptography?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Cryptography/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Cryptography?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Cryptography/absoluteLatest/)

---


## AllOverIt.Csv

Using [CsvHelper](https://joshclose.github.io/CsvHelper) to perform the actual writing of CSV content, this package provides a configuration based serializer that can export data using a model with fixed columns as well as dynamic columns derived from complex or array type properties.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Csv?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Csv/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Csv?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Csv/absoluteLatest/)

---


## AllOverIt.DependencyInjection

This package provides useful dependency injection related utilities such as registering and resolving 'named' services, auto service discovery and registration via a service registrar, and service decoration.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.DependencyInjection?color=E3505C)](https://www.nuget.org/packages/AllOverIt.DependencyInjection/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.DependencyInjection?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.DependencyInjection/absoluteLatest/)

---


## AllOverIt.EntityFrameworkCore

This package provides EntityFramework Core utilities such as a database migration helper and a value converter for **AllOverIt** based enriched enum types.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.EntityFrameworkCore?color=E3505C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.EntityFrameworkCore?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore/absoluteLatest/)

---


## AllOverIt.EntityFrameworkCore.Diagrams

In conjunction with [D2](https://d2lang.com/), this package will generate entity relationship diagrams for an EntityFramework Core DbContext.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.EntityFrameworkCore.Diagrams?color=E3505C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore.Diagrams/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.EntityFrameworkCore.Diagrams?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore.Diagrams/absoluteLatest/)

---


## AllOverIt.EntityFrameworkCore.Pagination

Using **AllOverIt.Pagination** as the basis for advanced keyset-based pagination, this package provides additional extensions for use with EntityFramework Core.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.EntityFrameworkCore.Pagination?color=E3505C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore.Pagination/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.EntityFrameworkCore.Pagination?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.EntityFrameworkCore.Pagination/absoluteLatest/)

---


## AllOverIt.Evaluator

This package contains a highly-extendable mathematical expression compiler and evaluator that includes constant, mutable, delegate, and lazily evaluated variables, offers implicit and explicit variable lookup, and supports custom arithmetic operators and operations.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Evaluator?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Evaluator/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Evaluator?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Evaluator/absoluteLatest/)

---


## AllOverIt.Filtering

This package adds comprehensive filtering support to any IQueryable with built-in provision for operations such as `Contains`, `StartsWith`, `EndsWith`, `In`, `NotIn`, `EqualTo`, `NotEqualTo`, `GreaterThan`, `LessThan`, `GreaterThanOrEqual`, and `LessThanOrEqual`.

It's also possible to create a custom predicate based on a Specification and there are options such as ignoring default (null) filter values and parameterizing query inputs that makes it ideal for use with EntityFramework Core.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Filtering?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Filtering/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Filtering?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Filtering/absoluteLatest/)

---


## AllOverIt.Fixture

This package contains a base fixture class with numerous helper methods to assist with scaffolding unit tests. Utilizes [AutoFixture](https://github.com/AutoFixture/AutoFixture) to do most of the hard work.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Fixture?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Fixture/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Fixture?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Fixture/absoluteLatest/)

---


## AllOverIt.Fixture.FakeItEasy

This package extends **AllOverIt.Fixture** to support [FakeItEasy](https://fakeiteasy.github.io/) integration.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Fixture.FakeItEasy?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Fixture.FakeItEasy/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Fixture.FakeItEasy?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Fixture.FakeItEasy/absoluteLatest/)

---


## AllOverIt.GenericHost

This package contains generic host helpers and convenience methods for setting up console applications that support dependency injection.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.GenericHost?color=E3505C)](https://www.nuget.org/packages/AllOverIt.GenericHost/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.GenericHost?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.GenericHost/absoluteLatest/)

---


## AllOverIt.Mapping

This package contains an object mapper that is mostly configuration free, but also capable of property exclusion, aliasing, null replacement, value conversion, and deep copying.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Mapping?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Mapping/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Mapping?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Mapping/absoluteLatest/)

---


## AllOverIt.Pagination

An advanced keyset-based pagination package that uses a fluent-style builder to create queries that cater for forward and backward navigation for any given deterministic base query.

Each page of results includes a 'continuation token' for the current, next, and previous page. These tokens can be used at a later time to navigate to the same location within the dataset, thereby somewhat overcoming the inability of random access traditionally associated with keyset-based navigation.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Pagination?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Pagination/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Pagination?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Pagination/absoluteLatest/)

---


## AllOverIt.Pipes

This package provides support for communication over anonymous pipes using [StreamReader](https://learn.microsoft.com/en-us/dotnet/api/system.io.streamreader) and [StreamWriter](https://learn.microsoft.com/en-us/dotnet/api/system.io.streamwriter), and strongly-typed message-based communication over named pipes using a binary serializer.

The named pipes can use the binary serializer from **AllOverIt.Serialization.Binary** or you can create your own.

![](https://img.shields.io/badge/.NET-8.0--windows-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0--windows-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0--windows-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Pipes?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Pipes/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Pipes?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Pipes/absoluteLatest/)

---


## AllOverIt.Reactive

This package contains utility extensions for use with [System.Reactive](https://github.com/dotnet/reactive).

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Reactive?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Reactive/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Reactive?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Reactive/absoluteLatest/)

---


## AllOverIt.ReactiveUI

This package contains utility extensions for use with [ReactiveUI](https://github.com/reactiveui/ReactiveUI).

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.ReactiveUI?color=E3505C)](https://www.nuget.org/packages/AllOverIt.ReactiveUI/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.ReactiveUI?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.ReactiveUI/absoluteLatest/)

---


## AllOverIt.ReactiveUI.Wpf

This package contains utility extensions for use with [ReactiveUI](https://github.com/reactiveui/ReactiveUI) and WPF.

![](https://img.shields.io/badge/.NET-8.0--windows-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0--windows-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0--windows-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.ReactiveUI.Wpf?color=E3505C)](https://www.nuget.org/packages/AllOverIt.ReactiveUI/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.ReactiveUI.Wpf?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.ReactiveUI/absoluteLatest/)

---


## AllOverIt.Serialization.Binary

This package provides enhanced support for binary serialization. Complex object graphs, lists, dictionaries and nullable values can all be dynamically serialized using reflection-based readers and writers or, for greater performance, a custom serializer per object within the graph.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Serialization.Binary?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Serialization.Binary/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Serialization.Binary?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Serialization.Binary/absoluteLatest/)

---


## AllOverIt.Serialization.Json.Abstractions

This package contains JSON serialization abstractions.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Serialization.Json.Abstractions?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.Abstractions/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Serialization.Json.Abstractions?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.Abstractions/absoluteLatest/)

---


## AllOverIt.Serialization.Json.NewtonSoft

This package contains a wrapper for [Newtonsoft](https://www.newtonsoft.com/json) JSON serialization based on **AllOverIt.Serialization.Json.Abstractions**.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Serialization.Json.NewtonSoft?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.NewtonSoft/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Serialization.Json.NewtonSoft?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.NewtonSoft/absoluteLatest/)

---


## AllOverIt.Serialization.Json.SystemText

This package contains a wrapper for [System.Text](https://learn.microsoft.com/en-us/dotnet/api/system.text.json) JSON serialization based on **AllOverIt.Serialization.Json.Abstractions**.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Serialization.Json.SystemText?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.SystemText/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Serialization.Json.SystemText?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Serialization.Json.SystemText/absoluteLatest/)

---


## AllOverIt.Validation

This package contains additional validators and extensions for use with [FluentValidation](https://docs.fluentvalidation.net/en/latest/). It includes an invoker that will select, and invoke, a registered validator based on a provided model.

Synchronous and Asynchronous validation is supported, along with extensions that make it easier to pass context information into a validator to keep it stateless.

Also available is a validation registrar that makes it possible to auto-register all validators within the same assembly. Validators can also be filtered based on a predicate.

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Validation?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Validation/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Validation?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Validation/absoluteLatest/)

---


## AllOverIt.Validation.Options

This package contains [Microsoft.Extensions.Options](https://learn.microsoft.com/en-us/dotnet/api/microsoft.extensions.options) validation using [FluentValidation](https://docs.fluentvalidation.net/en/latest/).

![](https://img.shields.io/badge/.NET-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET-6.0-FF8C67.svg)
![](https://img.shields.io/badge/.NET-standard2.1-6EBE50.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Validation.Options?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Validation.Options/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Validation.Options?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Validation.Options/absoluteLatest/)

---


## AllOverIt.Wpf

This package contains general purpose WPF utilities.

![](https://img.shields.io/badge/.NET--windows-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET--windows-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET--windows-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Wpf?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Wpf/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Wpf?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Wpf/absoluteLatest/)

---


## AllOverIt.Wpf.Controls

This package contains useful WPF controls.

![](https://img.shields.io/badge/.NET--windows-8.0-C56EE0.svg)
![](https://img.shields.io/badge/.NET--windows-7.0-55A9EE.svg)
![](https://img.shields.io/badge/.NET--windows-6.0-FF8C67.svg)

[![NuGet](https://img.shields.io/nuget/vpre/AllOverIt.Wpf.Controls?color=E3505C)](https://www.nuget.org/packages/AllOverIt.Wpf.Controls/absoluteLatest/)
[![NuGet](https://img.shields.io/nuget/dt/AllOverIt.Wpf.Controls?color=FFC33C)](https://www.nuget.org/packages/AllOverIt.Wpf.Controls/absoluteLatest/)

---

